aboutsummaryrefslogtreecommitdiff
path: root/gdb/python/py-symtab.c
diff options
context:
space:
mode:
authorCiro Santilli <ciro.santilli@gmail.com>2015-08-04 09:03:15 -0700
committerJoel Brobecker <brobecker@adacore.com>2015-08-04 09:50:53 -0700
commit4efd80aa8a99adbb38d0719ba56b07c9970793b5 (patch)
treefc1c126bc3f82c5301ae9b4b9199b888b2f3d690 /gdb/python/py-symtab.c
parent7e27a9d5f22f9f7ead11738b1546d0b5c737266b (diff)
downloadgdb-4efd80aa8a99adbb38d0719ba56b07c9970793b5.zip
gdb-4efd80aa8a99adbb38d0719ba56b07c9970793b5.tar.gz
gdb-4efd80aa8a99adbb38d0719ba56b07c9970793b5.tar.bz2
python: fix Linetable case to LineTable in docstrings and comments
The class is called LineTable, not Linetable, as specified by py-linetable.c/gdbpy_initialize_linetable: if (gdb_pymodule_addobject (gdb_module, "LineTable", gdb/ChangeLog: * python/py-linetable.c: Fix case of Linetable to LineTable in docstrings and code comments. * python/py-symtab.c: Same.
Diffstat (limited to 'gdb/python/py-symtab.c')
-rw-r--r--gdb/python/py-symtab.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/gdb/python/py-symtab.c b/gdb/python/py-symtab.c
index 796a7fc..7c428a4 100644
--- a/gdb/python/py-symtab.c
+++ b/gdb/python/py-symtab.c
@@ -207,8 +207,8 @@ stpy_static_block (PyObject *self, PyObject *args)
return block_to_block_object (block, SYMTAB_OBJFILE (symtab));
}
-/* Implementation of gdb.Symtab.linetable (self) -> gdb.Linetable.
- Returns a gdb.Linetable object corresponding to this symbol
+/* Implementation of gdb.Symtab.linetable (self) -> gdb.LineTable.
+ Returns a gdb.LineTable object corresponding to this symbol
table. */
static PyObject *
@@ -571,8 +571,8 @@ Return the global block of the symbol table." },
"static_block () -> gdb.Block.\n\
Return the static block of the symbol table." },
{ "linetable", stpy_get_linetable, METH_NOARGS,
- "linetable () -> gdb.Linetable.\n\
-Return the Linetable associated with this symbol table" },
+ "linetable () -> gdb.LineTable.\n\
+Return the LineTable associated with this symbol table" },
{NULL} /* Sentinel */
};